## Version 0.0.53

This new version introduces significant improvements to the chat recording and saving mechanism of the Llamabot. It also includes a minor refactor in the Zotero module.

### New Features

- Added chat recording and saving functionality. This feature includes the addition of `case-converter` to the project dependencies, the importation of `date` and `snakecase` from `datetime` and `caseconverter` respectively, the addition of `PromptRecorder` to record the chat, modification of the `chat` function to record and save the chat with a filename in snakecase format prefixed with the current date, and the addition of a `save` method in `PromptRecorder` to save the recorded chat to a specified path (22738e) (Eric Ma)
- Improved the chat recording and saving mechanism. The creation of the save path was moved to the beginning of the chat function, the save path now includes the date and the snakecased user choice, the save path is printed to the console when the user exits the chat, the save function now coerces the path argument to a pathlib.Path object for compatibility, and the save function is now called with the save path instead of a string for flexibility and ease of use (c44562) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- Removed the temperature parameter from the QueryBot instantiation in the chat function of the Zotero module. This simplifies the QueryBot configuration and does not affect the functionality of the bot (663594) (Eric Ma)
